==> nextcloud-22.2.10.tgz: nextcloud/apps/password_policy/l10n/hr.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "Zaporka je istekla, ponovno je postavite s pomoću značajke za povrat zaboravljene zaporke",
    "Password must not have been used recently before." : "Zaporka nije nedavno korištena.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Zaporka je među 1.000.000 najčešćih zaporki. Odaberite jedinstvenu zaporku.",
    "Password is present in compromised password list. Please choose a different password." : "Zaporka je prisutna na popisu kompromitiranih zaporki. Odaberite drugu zaporku.",
    "Password needs to be at least %s characters long." : "Zaporka mora biti dugačka najmanje %s.",
    "Password needs to contain at least one numeric character." : "Zaporka mora sadržavati barem jedan numerički znak.",
    "Password needs to contain at least one special character." : "Zaporka mora sadržavati barem jedan poseban znak.",
    "Password needs to contain at least one lower and one upper case character." : "Zaporka mora sadržavati barem jedno veliko i jedno malo slovo.",
    "Password policy" : "Pravila za upravljanje zaporkama",
    "Allows admins to configure a password policy" : "Omogućuju administratorima da konfiguriraju pravila za zaporke",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Omogućuju administratoru da definira određene preduvjete za zaporku, npr. minimalna dužina",
    "Saved" : "Spremljeno",
    "Minimum password length" : "Minimalna dužina zaporke",
    "User password history" : "Povijest zaporki korisnika",
    "Number of days until user password expires" : "Broj dana do isteka zaporke",
    "Number of login attempts before the user account is blocked (0 for no limit)" : "Broj pokušaja prijave prije blokiranja računa korisnika (0 za neograničeno)",
    "Forbid common passwords" : "Zabrani česte zaporke",
    "Enforce upper and lower case characters" : "Obavezna uporaba velikih i malih slova",
    "Enforce numeric characters" : "Obavezna uporaba numeričkih znakova",
    "Enforce special characters" : "Obavezna uporaba posebnih znakova",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Usporedite zaporku s popisom objavljenih zaporki s web-mjesta hasibeenpwned.com",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Ova provjera stvara kod kontrolni identifikacijski broj (hash) zaporke i šalje prvih 5 znakova tog broja API-ju web-mjesta hasibeenpwned.com s ciljem dohvaćanja popisa svih kontrolnih identifikacijskih brojeva koji počinju tim znakovima. Zatim se u instanci Nextclouda provjerava je li taj broj zaporke u skupu rezultata.",
    "Unknown error" : "Nepoznata pogreška",
    "Minimal length has to be a non negative number" : "Minimalna dužina mora biti pozitivan broj ili nula",
    "History size has to be a non negative number" : "Veličina povijesti mora biti pozitivan broj ili nula",
    "Expiration days have to be a non negative number" : "Broj dana do isteka mora biti pozitivan broj ili nula",
    "Maximum login attempts have to be a non negative number" : "Maksimalan broj prijava mora biti pozitivan broj ili nula"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");

==> nextcloud-28.0.8.tgz: nextcloud/apps/password_policy/l10n/hr.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "Zaporka je istekla, ponovno je postavite s pomoću značajke za povrat zaboravljene zaporke",
    "Password must not have been used recently before." : "Zaporka nije nedavno korištena.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Zaporka je među 1.000.000 najčešćih zaporki. Odaberite jedinstvenu zaporku.",
    "Password is present in compromised password list. Please choose a different password." : "Zaporka je prisutna na popisu kompromitiranih zaporki. Odaberite drugu zaporku.",
    "Password needs to be at least %s characters long." : "Zaporka mora biti dugačka najmanje %s.",
    "Password needs to contain at least one numeric character." : "Zaporka mora sadržavati barem jedan numerički znak.",
    "Password needs to contain at least one special character." : "Zaporka mora sadržavati barem jedan poseban znak.",
    "Password needs to contain at least one lower and one upper case character." : "Zaporka mora sadržavati barem jedno veliko i jedno malo slovo.",
    "Password policy" : "Pravila za upravljanje zaporkama",
    "Allows admins to configure a password policy" : "Omogućuju administratorima da konfiguriraju pravila za zaporke",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Omogućuju administratoru da definira određene preduvjete za zaporku, npr. minimalna dužina",
    "Minimum password length" : "Minimalna dužina zaporke",
    "User password history" : "Povijest zaporki korisnika",
    "Number of days until user password expires" : "Broj dana do isteka zaporke",
    "Forbid common passwords" : "Zabrani česte zaporke",
    "Enforce upper and lower case characters" : "Obavezna uporaba velikih i malih slova",
    "Enforce numeric characters" : "Obavezna uporaba numeričkih znakova",
    "Enforce special characters" : "Obavezna uporaba posebnih znakova",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Usporedite zaporku s popisom objavljenih zaporki s web-mjesta hasibeenpwned.com",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Ova provjera stvara kod kontrolni identifikacijski broj (hash) zaporke i šalje prvih 5 znakova tog broja API-ju web-mjesta hasibeenpwned.com s ciljem dohvaćanja popisa svih kontrolnih identifikacijskih brojeva koji počinju tim znakovima. Zatim se u instanci Nextclouda provjerava je li taj broj zaporke u skupu rezultata.",
    "Unknown error" : "Nepoznata pogreška",
    "Minimal length has to be a non negative number" : "Minimalna dužina mora biti pozitivan broj ili nula",
    "History size has to be a non negative number" : "Veličina povijesti mora biti pozitivan broj ili nula",
    "Expiration days have to be a non negative number" : "Broj dana do isteka mora biti pozitivan broj ili nula",
    "Maximum login attempts have to be a non negative number" : "Maksimalan broj prijava mora biti pozitivan broj ili nula",
    "Settings saved" : "Postavke spremljene"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
